@@ -40,7 +40,7 @@
 //! interact with the bitcoin P2P network.
 //!
 //! ```toml
-//! bdk = "0.11.0"
+//! bdk = "0.12.0"
 //! ```
 #![cfg_attr(
     feature = "electrum",
@@ -244,6 +244,9 @@ pub extern crate electrum_client;
 #[cfg(feature = "key-value-db")]
 pub extern crate sled;
 
+#[cfg(feature = "sqlite")]
+pub extern crate rusqlite;
+
 #[allow(unused_imports)]
 #[macro_use]
 pub(crate) mod error;
